==> isis-fish-4.1.0.1-sources.jar: fr/ifremer/isisfish/simulator/SimulationResultListener.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id: SimulationResultListener.java 3437 2011-07-08 11:26:05Z chatellier $
 * $HeadURL$
 * %%
 * Copyright (C) 2007 - 2011 Ifremer, Code Lutin, Cédric Pineau, Benjamin Poussin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.simulator;

import org.nuiton.math.matrix.MatrixND;

import fr.ifremer.isisfish.IsisFishException;
import fr.ifremer.isisfish.types.TimeStep;

/**
 * SimulationResultListener.java
 *
 * Created: 13 nov. 07 11:59:53
 *
 * @author poussin
 * @version $Revision: 3437 $
 *
 * Last update: $Date: 2011-07-08 13:26:05 +0200 (Fri, 08 Jul 2011) $
 * by : $Author: chatellier $
 */
public interface SimulationResultListener extends SimulationListener {

    public void addResult(SimulationContext context,
            TimeStep step, String name, MatrixND mat) throws IsisFishException;

}

==> isis-fish-4.3.0.2-20140616.104318-1-sources.jar: fr/ifremer/isisfish/simulator/SimulationResultListener.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id: SimulationResultListener.java 3798 2012-10-30 10:39:32Z echatellier $
 * $HeadURL$
 * %%
 * Copyright (C) 2007 - 2011 Ifremer, Code Lutin, Cédric Pineau, Benjamin Poussin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.simulator;

import org.nuiton.math.matrix.MatrixND;

import fr.ifremer.isisfish.IsisFishException;
import fr.ifremer.isisfish.types.TimeStep;

/**
 * SimulationResultListener.java
 *
 * Created: 13 nov. 07 11:59:53
 *
 * @author poussin
 * @version $Revision: 3798 $
 *
 * Last update: $Date: 2012-10-30 11:39:32 +0100 (mar. 30 oct. 2012) $
 * by : $Author: echatellier $
 */
public interface SimulationResultListener extends SimulationListener {

    public void addResult(SimulationContext context,
            TimeStep step, String name, MatrixND mat) throws IsisFishException;

}
